# Defined in testlib and overridden in testuse

package XAO::DO::Config2;
use strict;
use warnings;

sub config_2_lib {
    return 'Config2:Lib';
}

sub config_2_over {
    return 'Config2:Over';
}

1;
